import uvicorn

from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles
from fastapi.responses import FileResponse


async def catch_all(request, exc):
    return FileResponse("dist/index.html", status_code=200)


exceptions = {
    404: catch_all,
}

def run_server():

    app = FastAPI(exception_handlers=exceptions)


    app.mount("/", StaticFiles(directory="dist", html=True), name="static")


    uvicorn.run(app, port=5000, log_level="info")



import json

def inject_payload(content, payload):
        # insert a place holder easier to replace
        begin_payload, end_payload = "beginPayload:!0,", ",endPayload:!0"
        start_placeholder = content.index(begin_payload) + len(begin_payload)
        end_placeholder = content.index(end_payload)
        content = list(content)
        new_placeholder = str(hash("REPLACEMEPLEASE")) * 10
        content[start_placeholder:end_placeholder] = list(new_placeholder)
        content = "".join(content)

        new_payload = json.dumps(payload, separators=(',', ':'))  # separators with out whitespace
        trim_first_and_last_character = lambda s : s[1: -1]  # remove `{` and `}`
        new_payload = trim_first_and_last_character(new_payload)

        # inject the string in place of the placeholder
        content = content.replace(new_placeholder, new_payload)

        return content




import importlib.machinery
import types
from inspect import getmembers, isfunction
# I need to find all files that contain tests
from pathlib import Path

def discovery():
    p = Path('.')

    test_files = list(p.glob('**/*.spec.sy.py'))
    # then load them up dynamically

    each_module_tests = []

    if not test_files:
        print("NO TEST FILES YO")
    else:
        for i, test_file in enumerate(test_files):
            module_name = "test_modules_{i}"
            loader = importlib.machinery.SourceFileLoader(module_name, str(test_file))
            m = types.ModuleType(module_name)
            loader.exec_module(m)
            # then for each check if there's a test list
            tests = m.__dict__.get("TESTS", "notfound")
            if tests=="notfound":
                raise Exception("Your test files must contain a TESTS variable, which is a list of SimpleTest")
            # then make a list of list of tests
            each_module_tests.append(tests)

        print(each_module_tests)






